Use yarn instead of npm whenever relevant.

When running BioLib Apps, use [this file](prompts/biolib_run_apps.prompt.md) as context to understand how that works.

When working with BioLib App inputs, use [this file](prompts/biolib_app_inputs.prompt.md) as context to understand how the different files should be connected and formatted.
